@@ -1,4 +1,4 @@
-#!/bin/perl
+#!/usr/bin/env perl
 #============================================================= -*-perl-*-
 #
 # configure.pl: Configuration and installation program for BackupPC
@@ -19,7 +19,7 @@
 #   Craig Barratt <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2001-2007  Craig Barratt
+#   Copyright (C) 2001-2009  Craig Barratt
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@
 #
 #========================================================================
 #
-# Version 3.1.0, released 25 Nov 2007.
+# Version 3.2.0, released 31 Jul 2010.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -72,7 +72,7 @@ BackupPC cannot load the package $pkg, which is included in the
 BackupPC distribution.  This probably means you did not cd to the
 unpacked BackupPC distribution before running configure.pl, eg:
 
-    cd BackupPC-3.1.0
+    cd BackupPC-3.2.0
     ./configure.pl
 
 Please try again.
@@ -97,6 +97,7 @@ if ( !GetOptions(
             "cgi-dir=s",
             "compress-level=i",
             "config-path=s",
+            "config-override=s%",
             "config-dir=s",
             "data-dir=s",
             "dest-dir=s",
@@ -230,10 +231,15 @@ EOF
 # Create defaults for FHS setup
 #
 if ( $opts{fhs} ) {
-    $Conf{TopDir}       ||= "/data/BackupPC";
-    $Conf{ConfDir}      ||= $opts{"config-dir"} || "/etc/BackupPC";
-    $Conf{InstallDir}   ||= "/usr/local/BackupPC";
-    $Conf{LogDir}       ||= $opts{"log-dir"} || "/var/log/BackupPC";
+    $Conf{TopDir}       ||= $opts{"data-dir"}    || "/data/BackupPC";
+    $Conf{ConfDir}      ||= $opts{"config-dir"}  || "/etc/BackupPC";
+    $Conf{InstallDir}   ||= $opts{"install-dir"} || "/usr/local/BackupPC";
+    $Conf{LogDir}       ||= $opts{"log-dir"}     || "/var/log/BackupPC";
+} else {
+    $Conf{TopDir}       ||= $opts{"data-dir"}    || "/data/BackupPC";
+    $Conf{ConfDir}      ||= $opts{"config-dir"}  || "$Conf{TopDir}/conf";
+    $Conf{InstallDir}   ||= $opts{"install-dir"} || "/usr/local/BackupPC";
+    $Conf{LogDir}       ||= $opts{"log-dir"}     || "$Conf{TopDir}/log";
 }
 
 #
@@ -260,7 +266,7 @@ my %Programs = (
 foreach my $prog ( sort(keys(%Programs)) ) {
     my $path;
     foreach my $subProg ( split(/\//, $prog) ) {
-        $path = FindProgram("$ENV{PATH}:/bin:/usr/bin:/sbin:/usr/sbin",
+        $path = FindProgram("$ENV{PATH}:/usr/bin:/bin:/sbin:/usr/sbin",
                             $subProg) if ( !length($path) );
     }
     $Conf{$Programs{$prog}} = $path if ( !length($Conf{$Programs{$prog}}) );
@@ -401,10 +407,8 @@ BackupPC can compress pool files, but it needs the Compress::Zlib
 package installed (see www.cpan.org). Compression will provide around a
 40% reduction in pool size, at the expense of cpu time.  You can leave
 compression off and run BackupPC without compression, in which case you
-should leave the compression level at 0 (which means off).  You could
-install Compress::Zlib and turn compression on later, but read the
-documentation first about how to do this.  Or the better choice is
-to quit, install Compress::Zlib, and re-run configure.pl.
+should leave the compression level at 0 (which means off).  Or the better
+choice is to quit, install Compress::Zlib, and re-run configure.pl.
 
 EOF
     } elsif ( $Conf{CompressLevel} ) {
@@ -412,14 +416,12 @@ EOF
         print <<EOF;
 
 BackupPC now supports pool file compression.  Since you are upgrading
-BackupPC you probably have existing uncompressed backups.  You have
-several choices if you want to turn on compression.  You can run
-the script BackupPC_compressPool to convert everything to compressed
-form.  Or you can simply turn on compression, so that new backups
-will be compressed.  This will increase the pool storage requirement,
-since both uncompressed and compressed copies of files will be stored.
-But eventually the old uncompressed backups will expire, recovering
-the pool storage.  Please see the documentation for more details.
+BackupPC you probably have existing uncompressed backups.  You could
+turn on compression, so that new backups will be compressed.  This
+will increase the pool storage requirement, since both uncompressed
+and compressed copies of files will be stored. But eventually the old
+uncompressed backups will expire, recovering the pool storage.  Please
+see the documentation for more details.
 
 If you are not sure what to do, leave the Compression Level at 0,
 which disables compression.  You can always read the documentation
@@ -434,8 +436,6 @@ BackupPC now supports pool file compression, but it needs the
 Compress::Zlib module (see www.cpan.org).  For now, leave
 the compression level set at 0 to disable compression.  If you
 want you can install Compress::Zlib and turn compression on.
-Please see the documentation for more details about converting
-old backups to compressed form.
 
 EOF
     }
@@ -472,12 +472,12 @@ if ( $Conf{CgiDir} ne "" ) {
 
     print <<EOF;
 
-BackupPC's CGI script needs to display various GIF images that
-should be stored where Apache can serve them.  They should be
-placed somewhere under Apache's DocumentRoot.  BackupPC also
-needs to know the URL to access these images.  Example:
+BackupPC's CGI script needs to display various PNG/GIF images that
+should be stored where Apache can serve them.  They should be placed
+somewhere under Apache's DocumentRoot.  BackupPC also needs to know
+the URL to access these images.  Example:
 
-    Apache image directory:  /usr/local/apache/htdocs/BackupPC
+    Apache image directory:  /var/www/htdocs/BackupPC
     URL for image directory: /BackupPC
 
 The URL for the image directory should start with a slash.
@@ -528,6 +528,7 @@ foreach my $dir ( qw(bin doc
 		     lib/BackupPC/Storage
 		     lib/BackupPC/Xfer
 		     lib/BackupPC/Zip
+                     lib/Net/FTP
 		 ) ) {
     next if ( -d "$DestDir$Conf{InstallDir}/$dir" );
     mkpath("$DestDir$Conf{InstallDir}/$dir", 0, 0755);
@@ -591,7 +592,6 @@ foreach my $prog ( qw(
         bin/BackupPC_tarExtract
         bin/BackupPC_tarCreate
         bin/BackupPC_tarPCCopy
-        bin/BackupPC_compressPool
         bin/BackupPC_zipCreate
         bin/BackupPC_zcat
     ) ) {
@@ -630,6 +630,7 @@ foreach my $lib ( qw(
         lib/BackupPC/CGI/Summary.pm
         lib/BackupPC/CGI/View.pm
         lib/BackupPC/Config/Meta.pm
+        lib/BackupPC/Lang/cz.pm
         lib/BackupPC/Lang/de.pm
         lib/BackupPC/Lang/en.pm
         lib/BackupPC/Lang/es.pm
@@ -640,14 +641,18 @@ foreach my $lib ( qw(
         lib/BackupPC/Lang/pt_br.pm
         lib/BackupPC/Lang/zh_CN.pm
         lib/BackupPC/Storage/Text.pm
+        lib/BackupPC/Xfer.pm
         lib/BackupPC/Xfer/Archive.pm
-        lib/BackupPC/Xfer/BackupPCd.pm
-        lib/BackupPC/Xfer/Smb.pm
-        lib/BackupPC/Xfer/Tar.pm
+        lib/BackupPC/Xfer/Ftp.pm
+        lib/BackupPC/Xfer/Protocol.pm
         lib/BackupPC/Xfer/Rsync.pm
         lib/BackupPC/Xfer/RsyncDigest.pm
         lib/BackupPC/Xfer/RsyncFileIO.pm
+        lib/BackupPC/Xfer/Smb.pm
+        lib/BackupPC/Xfer/Tar.pm
         lib/BackupPC/Zip/FileMember.pm
+        lib/Net/FTP/AutoReconnect.pm
+        lib/Net/FTP/RetrHandle.pm
     ) ) {
     InstallFile($lib, "$DestDir$Conf{InstallDir}/$lib", 0444);
 }
@@ -662,7 +667,7 @@ if ( $Conf{CgiImageDir} ne "" ) {
     #
     # Install new CSS file, making a backup copy if necessary
     #
-    my $cssBackup = "$DestDir$Conf{CgiImageDir}/BackupPC_stnd.css.pre-3.1.0";
+    my $cssBackup = "$DestDir$Conf{CgiImageDir}/BackupPC_stnd.css.pre-3.2.0";
     if ( -f "$DestDir$Conf{CgiImageDir}/BackupPC_stnd.css" && !-f $cssBackup ) {
 	rename("$DestDir$Conf{CgiImageDir}/BackupPC_stnd.css", $cssBackup);
     }
@@ -677,10 +682,13 @@ if ( $Conf{CgiImageDir} ne "" ) {
 printf("Making init.d scripts\n");
 foreach my $init ( qw(gentoo-backuppc gentoo-backuppc.conf linux-backuppc
 		      solaris-backuppc debian-backuppc freebsd-backuppc
-                      suse-backuppc slackware-backuppc ) ) {
+                      freebsd-backuppc2 suse-backuppc slackware-backuppc ) ) {
     InstallFile("init.d/src/$init", "init.d/$init", 0444);
 }
 
+printf("Making Apache configuration file for suid-perl\n");
+InstallFile("httpd/src/BackupPC.conf", "httpd/BackupPC.conf", 0644);
+
 printf("Installing docs in $DestDir$Conf{InstallDir}/doc\n");
 foreach my $doc ( qw(BackupPC.pod BackupPC.html) ) {
     InstallFile("doc/$doc", "$DestDir$Conf{InstallDir}/doc/$doc", 0444);
@@ -857,10 +865,27 @@ if ( defined($Conf{CgiUserConfigEdit}) ) {
             =~ s/(\s*\$Conf\{.*?\}\s*=\s*).*/$1$value/s;
 }
 
+#
+# Apply any command-line configuration parameter settings
+#
+foreach my $param ( keys(%{$opts{"config-override"}}) ) {
+    my $val = eval { $opts{"config-override"}{$param} };
+    if ( @$ ) {
+        printf("Can't eval --config-override setting %s=%s\n",
+                        $param, $opts{"config-override"}{$param});
+        exit(1);
+    }
+    if ( !defined($newVars->{$param}) ) {
+        printf("Unkown config parameter %s in --config-override\n", $param);
+        exit(1);
+    }
+    $newConf->[$newVars->{$param}]{text} = $opts{"config-override"}{$param};
+}
+
 #
 # Now backup and write the config file
 #
-my $confCopy = "$dest.pre-3.1.0";
+my $confCopy = "$dest.pre-3.2.0";
 if ( -f $dest && !-f $confCopy ) {
     #
     # Make copy of config file, preserving ownership and modes
@@ -995,6 +1020,8 @@ sub InstallFile
                                     if ( $prog =~ /Lib.pm/ );
 	    s/__BACKUPPCUSER__/$Conf{BackupPCUser}/g;
 	    s/__CGIDIR__/$Conf{CgiDir}/g;
+            s/__IMAGEDIR__/$Conf{CgiImageDir}/g;
+            s/__IMAGEDIRURL__/$Conf{CgiImageDirURL}/g;
 	    if ( $first && /^#.*bin\/perl/ ) {
 		#
 		# Fill in correct path to perl (no taint for >= 2.0.1).
@@ -1277,7 +1304,7 @@ specified for a batch new install.
 
 Example:
 
-    --html-dir /usr/local/apache/htdocs/BackupPC
+    --html-dir /var/www/htdocs/BackupPC
 
 =item B<--html-dir-url URL>
 
@@ -1351,7 +1378,7 @@ Craig Barratt <cbarratt@users.sourceforge.net>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2001-2007  Craig Barratt.
+Copyright (C) 2001-2009  Craig Barratt.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
