@@ -10,7 +10,7 @@
 #   Rich Duzenbury (rduz at theduz dot com)
 #
 # COPYRIGHT
-#   Copyright (C) 2005-2007  Rich Duzenbury and Craig Barratt
+#   Copyright (C) 2005-2009  Rich Duzenbury and Craig Barratt
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #
 #========================================================================
 #
-# Version 3.1.0, released 25 Nov 2007.
+# Version 3.2.0, released 31 Jul 2010.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -135,7 +135,7 @@ sub action
     $incrSizeTot = sprintf("%.2f", $incrSizeTot / 1000);
     my $now      = timeStamp2(time);
 
-    print 'Content-type: text/xml', "\n\n",
+    print 'Content-type: text/xml', "\r\n\r\n",
           $rss->as_string;
 
 }
