@@ -10,7 +10,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2003  Craig Barratt
+#   Copyright (C) 2003-2009  Craig Barratt
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #
 #========================================================================
 #
-# Version 3.0.0, released 28 Jan 2007.
+# Version 3.2.0, released 31 Jul 2010.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -38,9 +38,10 @@ package BackupPC::CGI::Restore;
 
 use strict;
 use BackupPC::CGI::Lib qw(:all);
+use BackupPC::Xfer;
 use Data::Dumper;
 use File::Path;
-use Encode;
+use Encode qw/decode_utf8/;
 
 sub action
 {
@@ -80,7 +81,7 @@ EOF
 EOF
     }
     $hiddenStr .= "<input type=\"hidden\" name=\"fcbMax\" value=\"$In{fcbMax}\">\n";
-    $hiddenStr .= "<input type=\"hidden\" name=\"share\" value=\"${EscHTML($share)}\">\n";
+    $hiddenStr .= "<input type=\"hidden\" name=\"share\" value=\"${EscHTML(decode_utf8($share))}\">\n";
     $badFileCnt++ if ( $In{pathHdr} =~ m{(^|/)\.\.(/|$)} );
     $badFileCnt++ if ( $In{num} =~ m{(^|/)\.\.(/|$)} );
     if ( @fileList == 0 ) {
@@ -101,41 +102,51 @@ EOF
 	#
 	# Build list of hosts
 	#
-	my $hostDestSel;
-        my @hosts;
+	my($hostDestSel, @hosts, $gotThisHost, $directHost);
+
+        #
+        # Check all the hosts this user has permissions for
+        # and make sure direct restore is enabled.
+        # Note: after this loop we have the config for the
+        # last host in @hosts, not the original $In{host}!!
+        #
+        $directHost = $host;
 	foreach my $h ( GetUserHosts(1) ) {
-	    my $sel = " selected" if ( $h eq $In{host} );
-	    $hostDestSel .= "<option value=\"$h\"$sel>${EscHTML($h)}</option>";
-            push(@hosts, $h);
+            #
+            # Pick up the host's config file
+            #
+            $bpc->ConfigRead($h);
+            %Conf = $bpc->Conf();
+            if ( BackupPC::Xfer::restoreEnabled( \%Conf ) ) {
+                #
+                # Direct restore is enabled
+                #
+                push(@hosts, $h);
+                $gotThisHost = 1 if ( $h eq $host );
+            }
 	}
+        $directHost = $hosts[0] if ( !$gotThisHost && @hosts );
+        foreach my $h ( @hosts ) {
+            my $sel = " selected" if ( $h eq $directHost );
+            $hostDestSel .= "<option value=\"$h\"$sel>${EscHTML($h)}</option>";
+        }
 
         #
         # Tell the user what options they have
         #
         $pathHdr = decode_utf8($pathHdr);
-	$content .= eval("qq{$Lang->{Restore_Options_for__host2}}");
-
-        if ( @hosts == 1 ) {
-            #
-            # Pick up the host's config file
-            #
-            $bpc->ConfigRead($hosts[0]);
-            %Conf = $bpc->Conf();
-	}
+        $share   = decode_utf8($share);
+	$content = eval("qq{$Lang->{Restore_Options_for__host2}}");
 
 	#
 	# Decide if option 1 (direct restore) is available based
 	# on whether the restore command is set.
 	#
-	my $cmd = $Conf{XferMethod} eq "smb" ? $Conf{SmbClientRestoreCmd}
-		: $Conf{XferMethod} eq "tar" ? $Conf{TarClientRestoreCmd}
-		: $Conf{XferMethod} eq "archive" ? undef
-		: $Conf{RsyncRestoreArgs};
-	if ( defined($cmd) ) {
+	if ( $hostDestSel ne "" ) {
 	    $content .= eval(
 		"qq{$Lang->{Restore_Options_for__host_Option1}}");
 	} else {
-	    my $hostDest = $hosts[0];
+	    my $hostDest = $In{host};
 	    $content .= eval(
 		"qq{$Lang->{Restore_Options_for__host_Option1_disabled}}");
 	}
@@ -249,11 +260,7 @@ EOF
         # Decide if option 1 (direct restore) is available based
         # on whether the restore command is set.
         #
-        my $cmd = $Conf{XferMethod} eq "smb" ? $Conf{SmbClientRestoreCmd}
-                : $Conf{XferMethod} eq "tar" ? $Conf{TarClientRestoreCmd}
-                : $Conf{XferMethod} eq "archive" ? undef
-                : $Conf{RsyncRestoreArgs};
-        if ( !defined($cmd) ) {
+        unless ( BackupPC::Xfer::restoreEnabled( \%Conf ) ) {
 	    ErrorExit(eval("qq{$Lang->{Restore_Options_for__host_Option1_disabled}}"));
         }
 
@@ -323,7 +330,7 @@ EOF
                          [  \%restoreReq],
                          [qw(*RestoreReq)]);
         $dump->Indent(1);
-        mkpath("$TopDir/pc/$hostDest", 0, 0777)
+        eval { mkpath("$TopDir/pc/$hostDest", 0, 0777) }
                                     if ( !-d "$TopDir/pc/$hostDest" );
 	my $openPath = "$TopDir/pc/$hostDest/$reqFileName";
         if ( open(REQ, ">", $openPath) ) {
