@@ -10,7 +10,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2004  Craig Barratt
+#   Copyright (C) 2004-2009  Craig Barratt
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #
 #========================================================================
 #
-# Version 3.0.0, released 28 Jan 2007.
+# Version 3.2.0, released 31 Jul 2010.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -80,6 +80,7 @@ use vars qw(%ConfigMeta);
     MaxBackupPCNightlyJobs => "integer",
     BackupPCNightlyPeriod  => "integer",
     MaxOldLogFiles      => "integer",
+    CmdQueueNice        => "integer",
 
     SshPath	 	=> {type => "execPath", undefIfEmpty => 1},
     NmbLookupPath 	=> {type => "execPath", undefIfEmpty => 1},
@@ -194,12 +195,16 @@ use vars qw(%ConfigMeta);
     ######################################################################
     XferMethod => {
 	    type   => "select",
-	    values => [qw(archive rsync rsyncd smb tar)],
+	    values => [qw(archive ftp rsync rsyncd smb tar)],
     },
     XferLogLevel	=> "integer",
 
     ClientCharset       => "string",
+    ClientCharsetLegacy => "string",
 
+    ######################################################################
+    # Smb Configuration
+    ######################################################################
     SmbShareName 	=> {
 	    type   => "list",
 	    child  => "string",
@@ -209,8 +214,11 @@ use vars qw(%ConfigMeta);
     SmbClientPath 	=> {type => "execPath", undefIfEmpty => 1},
     SmbClientFullCmd 	=> "string",
     SmbClientIncrCmd 	=> "string",
-    SmbClientRestoreCmd => "string",
+    SmbClientRestoreCmd => {type => "string", undefIfEmpty => 1},
 
+    ######################################################################
+    # Tar Configuration
+    ######################################################################
     TarShareName 	=> {
 	    type   => "list",
 	    child  => "string",
@@ -218,9 +226,12 @@ use vars qw(%ConfigMeta);
     TarClientCmd	=> "string",
     TarFullArgs 	=> "string",
     TarIncrArgs		=> "string",
-    TarClientRestoreCmd	=> "string",
+    TarClientRestoreCmd	=> {type => "string", undefIfEmpty => 1},
     TarClientPath 	=> {type => "string", undefIfEmpty => 1},
 
+    ######################################################################
+    # Rsync Configuration
+    ######################################################################
     RsyncShareName 	=> {
 	    type   => "list",
 	    child  => "string",
@@ -229,28 +240,53 @@ use vars qw(%ConfigMeta);
     RsyncClientCmd 	=> "string",
     RsyncClientRestoreCmd => "string",
 
+    ######################################################################
+    # Rsyncd Configuration
+    ######################################################################
     RsyncdClientPort	=> "integer",
     RsyncdUserName 	=> "string",
     RsyncdPasswd 	=> "string",
     RsyncdAuthRequired	=> "boolean",
 
+    ######################################################################
+    # Rsync(d) Options
+    ######################################################################
     RsyncCsumCacheVerifyProb => "float",
     RsyncArgs	 	=> {
-	    type   => "list",
-	    emptyOk => 1,
-	    child  => "string",
+	    type         => "list",
+	    emptyOk      => 1,
+	    child        => "string",
+    },
+    RsyncArgsExtra	 => {
+	    type         => "list",
+	    emptyOk      => 1,
+	    child        => "string",
     },
     RsyncRestoreArgs	=> {
-	    type   => "list",
-	    emptyOk => 1,
-	    child  => "string",
+	    type         => "list",
+	    emptyOk      => 1,
+            undefIfEmpty => 1,
+	    child        => "string",
     },
 
-    BackupPCdCmd        => "string",
-    BackupPCdPath       => "string",
-    BackupPCdShareName  => "string",
-    BackupPCdRestoreCmd => "string",
+    ######################################################################
+    # FTP Configuration
+    ######################################################################
+    FtpShareName        => {
+            type  => "list",
+            child => "string",
+    },
+    FtpUserName         => "string",
+    FtpPasswd           => "string",
+    FtpPassive          => "boolean",
+    FtpBlockSize        => "integer",
+    FtpPort             => "integer",
+    FtpTimeout          => "integer",
+    FtpFollowSymlinks   => "boolean",
 
+    ######################################################################
+    # Archive Configuration
+    ######################################################################
     ArchiveDest 	=> "string",
     ArchiveComp		=> {
 	    type   => "select",
@@ -260,6 +296,9 @@ use vars qw(%ConfigMeta);
     ArchiveSplit	=> "float",
     ArchiveClientCmd 	=> "string",
 
+    ######################################################################
+    # Other Client Configuration
+    ######################################################################
     NmbLookupCmd 	=> "string",
     NmbLookupFindHostCmd => "string",
 
@@ -312,11 +351,11 @@ use vars qw(%ConfigMeta);
     CgiURL	 	=> "string",
     Language	 	=> {
 	    type   => "select",
-	    values => [qw(de en es fr it nl pt_br)],
+	    values => [qw(cz de en es fr it nl pl pt_br zh_CN)],
     },
     CgiUserHomePageCheck => "string",
     CgiUserUrlCreate    => "string",
-    CgiDateFormatMMDD	=> "boolean",
+    CgiDateFormatMMDD	=> "integer",
     CgiNavBarAdminAllHosts => "boolean",
     CgiSearchBoxEnable 	=> "boolean",
     CgiNavBarLinks	=> {
@@ -382,6 +421,7 @@ use vars qw(%ConfigMeta);
                 XferMethod                => "boolean",
                 XferLogLevel              => "boolean",
                 ClientCharset             => "boolean",
+                ClientCharsetLegacy       => "boolean",
                 SmbShareName              => "boolean",
                 SmbShareUserName          => "boolean",
                 SmbSharePasswd            => "boolean",
@@ -396,14 +436,24 @@ use vars qw(%ConfigMeta);
                 TarClientRestoreCmd       => "boolean",
                 RsyncShareName            => "boolean",
                 RsyncdClientPort          => "boolean",
+                RsyncdUserName            => "boolean",
                 RsyncdPasswd              => "boolean",
                 RsyncdAuthRequired        => "boolean",
                 RsyncCsumCacheVerifyProb  => "boolean",
                 RsyncArgs                 => "boolean",
+                RsyncArgsExtra            => "boolean",
                 RsyncRestoreArgs          => "boolean",
                 RsyncClientCmd            => "boolean",
                 RsyncClientPath           => "boolean",
                 RsyncClientRestoreCmd     => "boolean",
+                FtpShareName              => "boolean",
+                FtpUserName               => "boolean",
+                FtpPasswd                 => "boolean",
+                FtpBlockSize              => "boolean",
+                FtpPort                   => "boolean",
+                FtpTimeout                => "boolean",
+                FtpFollowSymlinks         => "boolean",
+                FtpRestoreEnabled         => "boolean",
                 ArchiveDest               => "boolean",
                 ArchiveComp               => "boolean",
                 ArchivePar                => "boolean",
