@@ -15,7 +15,7 @@
 #   Based on Archive::Zip::FileMember, Copyright (c) 2000 Ned Konz.
 #
 # COPYRIGHT
-#   Copyright (C) 2002-2007  Craig Barratt
+#   Copyright (C) 2002-2009  Craig Barratt
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@
 #
 #========================================================================
 #
-# Version 3.1.0, released 25 Nov 2007.
+# Version 3.2.0, released 31 Jul 2010.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -133,3 +133,19 @@ sub extractToFileNamed	# BackupPC::Zip::FileMember
 {
     die("BackupPC::Zip::FileMember::extractToFileNamed not supported\n");
 }
+
+#
+# There is a bug in Archive::Zip 1.30 that causes BackupPC_zipCreate
+# to fail when compression is on and it is writing to an unseekable
+# output file (eg: pipe or socket); see:
+#
+#    https://rt.cpan.org/Public/Bug/Display.html?id=54827
+#
+# We overload the bitFlag function here to avoid the bug.
+#
+sub bitFlag
+{
+    my $self = shift;
+
+    return $self->{bitFlag};
+}
